==> members-facade-1.0.2-20190110.084159-7-sources.jar: com/bizvane/members/facade/vo/MbrElectCardVO.java <==
package com.bizvane.members.facade.vo;

import com.bizvane.members.facade.models.po.MbrCustomEntryPO;
import com.bizvane.members.facade.models.po.MbrElectCardPO;
import java.util.Date;
import java.util.List;

/**
 * Created by 26095 on 2019/1/8.
 */
public class MbrElectCardVO{
    private List<MbrCustomEntryPO> mbrCustomEntryPOList;

    public List<MbrCustomEntryPO> getMbrCustomEntryPOList() {
        return mbrCustomEntryPOList;
    }

    public void setMbrCustomEntryPOList(List<MbrCustomEntryPO> mbrCustomEntryPOList) {
        this.mbrCustomEntryPOList = mbrCustomEntryPOList;
    }
    private String qrcode;

    public String getQrcode() {
        return qrcode;
    }

    public void setQrcode(String qrcode) {
        this.qrcode = qrcode;
    }

    /**
     * 只读. . mbr_meber_card_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "", name = "mbrMeberCardId", required = false, example = "")
    private Long mbrMeberCardId;
    /**
     * 只读. 会员卡卡套编号. card_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "会员卡卡套编号", name = "cardId", required = false, example = "")
    private String cardId;
    /**
     * 只读. 企业id. sys_company_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "企业id", name = "sysCompanyId", required = false, example = "")
    private Long sysCompanyId;
    /**
     * 只读. 品牌id. sys_brand_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "品牌id", name = "sysBrandId", required = false, example = "")
    private Long sysBrandId;
    /**
     * 只读. 商户名称. merchant_name
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "商户名称", name = "merchantName", required = false, example = "")
    private String merchantName;
    /**
     * 只读. 商户logo. merchant_logo
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "商户logo", name = "merchantLogo", required = false, example = "")
    private String merchantLogo;
    /**
     * 只读. 会员卡名称. mbr_card_name
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "会员卡名称", name = "mbrCardName", required = false, example = "")
    private String mbrCardName;
    /**
     * 只读. 卡券封面. card_cover
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "卡券封面", name = "cardCover", required = false, example = "")
    private String cardCover;
    /**
     * 只读. 对应等级. card_level
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "对应等级", name = "cardLevel", required = false, example = "")
    private String cardLevel;
    /**
     * 只读. 中部按钮名称. center_btn
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "中部按钮名称", name = "centerBtn", required = false, example = "")
    private String centerBtn;
    /**
     * 只读. 中部按钮标题. center_title
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "中部按钮标题", name = "centerTitle", required = false, example = "")
    private String centerTitle;
    /**
     * 只读. 中部按钮url. center_url
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "中部按钮url", name = "centerUrl", required = false, example = "")
    private String centerUrl;
    /**
     * 只读. 展示权益 1:积分 2:等级 3:余额 4:优惠券 逗号隔开. display_equity
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "展示权益 1:积分 2:等级 3:余额 4:优惠券 逗号隔开", name = "displayEquity", required = false, example = "")
    private String displayEquity;
    /**
     * 只读. 会员特权. mbr_privilege
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "会员特权", name = "mbrPrivilege", required = false, example = "")
    private String mbrPrivilege;
    /**
     * 只读. 使用须知. instructions
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "使用须知", name = "instructions", required = false, example = "")
    private String instructions;
    /**
     * 只读. 备注. remark
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "备注", name = "remark", required = false, example = "")
    private String remark;
    /**
     * 只读. 创建人id. create_user_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
    private Long createUserId;
    /**
     * 只读. 创建人名. create_user_name
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "创建人名", name = "createUserName", required = false, example = "")
    private String createUserName;
    /**
     * 只读. 创建时间. create_date
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "创建时间", name = "createDate", required = false, example = "")
    private Date createDate;
    /**
     * 只读. 修改人id. modified_user_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
    private Long modifiedUserId;
    /**
     * 只读. 修改人名. modified_user_name
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "修改人名", name = "modifiedUserName", required = false, example = "")
    private String modifiedUserName;
    /**
     * 只读. 修改时间. modified_date
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "修改时间", name = "modifiedDate", required = false, example = "")
    private Date modifiedDate;
    /**
     * 只读. 数据有效性：1=有效；0=无效. valid
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "数据有效性：1=有效；0=无效", name = "valid", required = false, example = "")
    private Boolean valid;
    /**
     * 只读. 版本号. version
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "版本号", name = "version", required = false, example = "")
    private Integer version;
    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Long getMbrMeberCardId() {
        return mbrMeberCardId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setMbrMeberCardId(Long mbrMeberCardId) {
        this.mbrMeberCardId = mbrMeberCardId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getCardId() {
        return cardId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCardId(String cardId) {
        this.cardId = cardId == null ? null : cardId.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Long getSysBrandId() {
        return sysBrandId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getMerchantName() {
        return merchantName;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setMerchantName(String merchantName) {
        this.merchantName = merchantName == null ? null : merchantName.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getMerchantLogo() {
        return merchantLogo;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setMerchantLogo(String merchantLogo) {
        this.merchantLogo = merchantLogo == null ? null : merchantLogo.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getMbrCardName() {
        return mbrCardName;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setMbrCardName(String mbrCardName) {
        this.mbrCardName = mbrCardName == null ? null : mbrCardName.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getCardCover() {
        return cardCover;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCardCover(String cardCover) {
        this.cardCover = cardCover == null ? null : cardCover.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getCardLevel() {
        return cardLevel;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCardLevel(String cardLevel) {
        this.cardLevel = cardLevel == null ? null : cardLevel.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getCenterBtn() {
        return centerBtn;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCenterBtn(String centerBtn) {
        this.centerBtn = centerBtn == null ? null : centerBtn.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getCenterTitle() {
        return centerTitle;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCenterTitle(String centerTitle) {
        this.centerTitle = centerTitle == null ? null : centerTitle.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getCenterUrl() {
        return centerUrl;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCenterUrl(String centerUrl) {
        this.centerUrl = centerUrl == null ? null : centerUrl.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getDisplayEquity() {
        return displayEquity;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setDisplayEquity(String displayEquity) {
        this.displayEquity = displayEquity == null ? null : displayEquity.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getMbrPrivilege() {
        return mbrPrivilege;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setMbrPrivilege(String mbrPrivilege) {
        this.mbrPrivilege = mbrPrivilege == null ? null : mbrPrivilege.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getInstructions() {
        return instructions;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setInstructions(String instructions) {
        this.instructions = instructions == null ? null : instructions.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setRemark(String remark) {
        this.remark = remark == null ? null : remark.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Long getCreateUserId() {
        return createUserId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getCreateUserName() {
        return createUserName;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName == null ? null : createUserName.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Date getCreateDate() {
        return createDate;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getModifiedUserName() {
        return modifiedUserName;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Date getModifiedDate() {
        return modifiedDate;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Boolean getValid() {
        return valid;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setValid(Boolean valid) {
        this.valid = valid;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Integer getVersion() {
        return version;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setVersion(Integer version) {
        this.version = version;
    }

}

==> members-facade-1.0.2-20190117.083929-16-sources.jar: com/bizvane/members/facade/vo/MbrElectCardVO.java <==
package com.bizvane.members.facade.vo;

import com.bizvane.members.facade.models.po.MbrCustomEntryPO;
import com.bizvane.members.facade.models.po.MbrElectCardPO;
import java.util.Date;
import java.util.List;

/**
 * Created by 26095 on 2019/1/8.
 */
public class MbrElectCardVO{
    private List<MbrCustomEntryPO> mbrCustomEntryPOList;

    public List<MbrCustomEntryPO> getMbrCustomEntryPOList() {
        return mbrCustomEntryPOList;
    }

    public void setMbrCustomEntryPOList(List<MbrCustomEntryPO> mbrCustomEntryPOList) {
        this.mbrCustomEntryPOList = mbrCustomEntryPOList;
    }
    private String redirect;

    public String getRedirect() {
        return redirect;
    }

    public void setRedirect(String redirect) {
        this.redirect = redirect;
    }

    private String qrcode;

    public String getQrcode() {
        return qrcode;
    }

    public void setQrcode(String qrcode) {
        this.qrcode = qrcode;
    }

    /**
     * 只读. . mbr_meber_card_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "", name = "mbrMeberCardId", required = false, example = "")
    private Long mbrMeberCardId;
    /**
     * 只读. 会员卡卡套编号. card_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "会员卡卡套编号", name = "cardId", required = false, example = "")
    private String cardId;
    /**
     * 只读. 企业id. sys_company_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "企业id", name = "sysCompanyId", required = false, example = "")
    private Long sysCompanyId;
    /**
     * 只读. 品牌id. sys_brand_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "品牌id", name = "sysBrandId", required = false, example = "")
    private Long sysBrandId;
    /**
     * 只读. 商户名称. merchant_name
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "商户名称", name = "merchantName", required = false, example = "")
    private String merchantName;
    /**
     * 只读. 商户logo. merchant_logo
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "商户logo", name = "merchantLogo", required = false, example = "")
    private String merchantLogo;
    /**
     * 只读. 会员卡名称. mbr_card_name
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "会员卡名称", name = "mbrCardName", required = false, example = "")
    private String mbrCardName;
    /**
     * 只读. 卡券封面. card_cover
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "卡券封面", name = "cardCover", required = false, example = "")
    private String cardCover;
    /**
     * 只读. 对应等级. card_level
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "对应等级", name = "cardLevel", required = false, example = "")
    private String cardLevel;
    /**
     * 只读. 中部按钮名称. center_btn
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "中部按钮名称", name = "centerBtn", required = false, example = "")
    private String centerBtn;
    /**
     * 只读. 中部按钮标题. center_title
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "中部按钮标题", name = "centerTitle", required = false, example = "")
    private String centerTitle;
    /**
     * 只读. 中部按钮url. center_url
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "中部按钮url", name = "centerUrl", required = false, example = "")
    private String centerUrl;
    /**
     * 只读. 展示权益 1:积分 2:等级 3:余额 4:优惠券 逗号隔开. display_equity
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "展示权益 1:积分 2:等级 3:余额 4:优惠券 逗号隔开", name = "displayEquity", required = false, example = "")
    private String displayEquity;
    /**
     * 只读. 会员特权. mbr_privilege
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "会员特权", name = "mbrPrivilege", required = false, example = "")
    private String mbrPrivilege;
    /**
     * 只读. 使用须知. instructions
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "使用须知", name = "instructions", required = false, example = "")
    private String instructions;
    /**
     * 只读. 备注. remark
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "备注", name = "remark", required = false, example = "")
    private String remark;
    /**
     * 只读. 创建人id. create_user_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "创建人id", name = "createUserId", required = false, example = "")
    private Long createUserId;
    /**
     * 只读. 创建人名. create_user_name
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "创建人名", name = "createUserName", required = false, example = "")
    private String createUserName;
    /**
     * 只读. 创建时间. create_date
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "创建时间", name = "createDate", required = false, example = "")
    private Date createDate;
    /**
     * 只读. 修改人id. modified_user_id
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "修改人id", name = "modifiedUserId", required = false, example = "")
    private Long modifiedUserId;
    /**
     * 只读. 修改人名. modified_user_name
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "修改人名", name = "modifiedUserName", required = false, example = "")
    private String modifiedUserName;
    /**
     * 只读. 修改时间. modified_date
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "修改时间", name = "modifiedDate", required = false, example = "")
    private Date modifiedDate;
    /**
     * 只读. 数据有效性：1=有效；0=无效. valid
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "数据有效性：1=有效；0=无效", name = "valid", required = false, example = "")
    private Boolean valid;
    /**
     * 只读. 版本号. version
     * @mbg.generated  2019-01-08 10:20:38
     */
    @io.swagger.annotations.ApiModelProperty(value = "版本号", name = "version", required = false, example = "")
    private Integer version;
    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Long getMbrMeberCardId() {
        return mbrMeberCardId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setMbrMeberCardId(Long mbrMeberCardId) {
        this.mbrMeberCardId = mbrMeberCardId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getCardId() {
        return cardId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCardId(String cardId) {
        this.cardId = cardId == null ? null : cardId.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Long getSysCompanyId() {
        return sysCompanyId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setSysCompanyId(Long sysCompanyId) {
        this.sysCompanyId = sysCompanyId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Long getSysBrandId() {
        return sysBrandId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setSysBrandId(Long sysBrandId) {
        this.sysBrandId = sysBrandId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getMerchantName() {
        return merchantName;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setMerchantName(String merchantName) {
        this.merchantName = merchantName == null ? null : merchantName.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getMerchantLogo() {
        return merchantLogo;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setMerchantLogo(String merchantLogo) {
        this.merchantLogo = merchantLogo == null ? null : merchantLogo.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getMbrCardName() {
        return mbrCardName;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setMbrCardName(String mbrCardName) {
        this.mbrCardName = mbrCardName == null ? null : mbrCardName.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getCardCover() {
        return cardCover;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCardCover(String cardCover) {
        this.cardCover = cardCover == null ? null : cardCover.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getCardLevel() {
        return cardLevel;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCardLevel(String cardLevel) {
        this.cardLevel = cardLevel == null ? null : cardLevel.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getCenterBtn() {
        return centerBtn;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCenterBtn(String centerBtn) {
        this.centerBtn = centerBtn == null ? null : centerBtn.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getCenterTitle() {
        return centerTitle;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCenterTitle(String centerTitle) {
        this.centerTitle = centerTitle == null ? null : centerTitle.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getCenterUrl() {
        return centerUrl;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCenterUrl(String centerUrl) {
        this.centerUrl = centerUrl == null ? null : centerUrl.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getDisplayEquity() {
        return displayEquity;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setDisplayEquity(String displayEquity) {
        this.displayEquity = displayEquity == null ? null : displayEquity.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getMbrPrivilege() {
        return mbrPrivilege;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setMbrPrivilege(String mbrPrivilege) {
        this.mbrPrivilege = mbrPrivilege == null ? null : mbrPrivilege.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getInstructions() {
        return instructions;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setInstructions(String instructions) {
        this.instructions = instructions == null ? null : instructions.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getRemark() {
        return remark;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setRemark(String remark) {
        this.remark = remark == null ? null : remark.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Long getCreateUserId() {
        return createUserId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCreateUserId(Long createUserId) {
        this.createUserId = createUserId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getCreateUserName() {
        return createUserName;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName == null ? null : createUserName.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Date getCreateDate() {
        return createDate;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Long getModifiedUserId() {
        return modifiedUserId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setModifiedUserId(Long modifiedUserId) {
        this.modifiedUserId = modifiedUserId;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public String getModifiedUserName() {
        return modifiedUserName;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setModifiedUserName(String modifiedUserName) {
        this.modifiedUserName = modifiedUserName == null ? null : modifiedUserName.trim();
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Date getModifiedDate() {
        return modifiedDate;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setModifiedDate(Date modifiedDate) {
        this.modifiedDate = modifiedDate;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Boolean getValid() {
        return valid;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setValid(Boolean valid) {
        this.valid = valid;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public Integer getVersion() {
        return version;
    }

    /**
     * 只读.
     * @mbg.generated  2019-01-08 10:20:38
     */
    public void setVersion(Integer version) {
        this.version = version;
    }

}
